import { AfterViewInit, Component, ViewChild } from '@angular/core';
import { BryntumSchedulerComponent } from '@bryntum/scheduler-angular';
import { DateHelper, Scheduler } from '@bryntum/scheduler';
import AppEventModel, { DependencyDataModel, ResourceDataModel } from '../lib/AppEventModel';
import { schedulerConfig } from '../app.config';

@Component({
    selector    : 'app-home',
    templateUrl : 'home.page.html',
    styleUrls   : ['home.page.scss']
})
export class HomePage implements AfterViewInit {

    @ViewChild(BryntumSchedulerComponent, { static : false }) schedulerComponent: BryntumSchedulerComponent;

    schedulerConfig: any = schedulerConfig;

    resources: ResourceDataModel[] = [
        {"id": "a", "name": "Arcady", "role": "Developer"},
        {"id": "b", "name": "Dave", "role": "Sales"},
        {"id": "c", "name": "Henrik", "role": "Sales"},
        {"id": "f", "name": "Celia", "role": "CEO"},
        {"id": "g", "name": "Lee", "role": "CTO"},
        {"id": "d", "name": "Madison", "role": "Developer"},
        {"id": "e", "name": "Maxim", "role": "Developer"},
        {"id": "h", "name": "Amit", "role": "Sales"},
        {"id": "i", "name": "Kate", "role": "Developer"},
        {"id": "j", "name": "Mark", "role": "Developer"},
        {"id": "k", "name": "Emilia", "role": "Developer"}
      ];

    events = [
        {
          "id"        : 'id1',
          "resourceId": "a",
          "name"      : "Meeting #1",
          "desc"      : "Discuss new features",
          "startDate" : "2018-02-07 11:00",
          "endDate"   : "2018-02-07 14:00",
          "eventType" : "Meeting",
          "eventColor": "blue",
          "iconCls"   : "b-fa b-fa-calendar"
        },
        {
          "id"        : 'id2',
          "resourceId": "b",
          "name"      : "Meeting #2",
          "desc"      : "Strategy meeting",
          "startDate" : "2018-02-07 12:00",
          "endDate"   : "2018-02-07 15:00",
          "eventType" : "Meeting",
          "eventColor": "blue",
          "iconCls"   : "b-fa b-fa-calendar"
        },
        {
          "id"        : 'id3',
          "resourceId": "c",
          "name"      : "Meeting #3",
          "desc"      : "Emerging markets",
          "startDate" : "2018-02-07 13:00",
          "endDate"   : "2018-02-07 16:00",
          "eventType" : "Meeting",
          "eventColor": "blue",
          "iconCls"   : "b-fa b-fa-calendar"
        },
      ];

    // application properties
    scheduler: Scheduler;
    selectedEventName  = '';
    pickerDate = new Date(2018, 1, 7);
    barMargin = 5;

    ngAfterViewInit(): void {
        this.scheduler = this.schedulerComponent.instance;
    }

    //add event button click handled here
    onAddEventClick(): void {
        const { scheduler } = this;

        // const event = new AppEventModel({
        //     resourceId   : scheduler.resourceStore.first.id,
        //     startDate    : scheduler.startDate,
        //     duration     : 2,
        //     durationUnit : 'hour',
        //     name         : 'Meet CEO',
        //     desc         : 'Discuss project',
        //     eventType    : 'Meeting',
        //     eventColor   : 'red'
        // });

        //scheduler.editEvent(event);
    }

    public addDataClick(): void {   
    try {
        // Events
        const eventsToAdd = this.events.map(ev => {
          const model = new AppEventModel();
          model.copyData(ev);          
          return model;
        });
      
        this.scheduler.eventStore.add(eventsToAdd);

        // Resources
        const resourcesToAdd = this.resources.map(res => {
          const model: ResourceDataModel = {
            id: res.id,
            name: res.name,
            role: res.role
          };
          
          return model;
        });

        this.scheduler.resourceStore.add(resourcesToAdd);

        // Dependency
        this.scheduler.dependencyStore.beginBatch();
        this.scheduler.dependencyStore.removeAll();

        const deps: DependencyDataModel[] = [{
          id: 1,
          from: this.events[0].id,
          to: this.events[1].id
        }];

        this.scheduler.dependencyStore.add(deps);
        this.scheduler.dependencyStore.endBatch();

      } catch (error) {
        console.error(error);
      }
    }

    //remove event button click handled here
    onRemoveEventClick(): void {
        const { scheduler } = this;
        scheduler.eventStore.remove(scheduler.selectedEvents);
    }

    onBarMarginChange({ value }): void {
        this.barMargin = value;
    }

    onEventSelectionChange(): void {
        if (this.scheduler.selectedEvents.length > 0) {
            this.selectedEventName = this.scheduler.selectedEvents[0].name;
        }
        else {
            this.selectedEventName = '';
        }
    }

    onReleaseEvent(): void {
        this.selectedEventName = '';
    }

    onDatePickerChange({ value }) : void {
        this.scheduler.setTimeSpan(
            DateHelper.add(value, 8, 'hour'),
            DateHelper.add(value, 18, 'hour')
        );
    }
}
